// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
import turfCircle from "@turf/circle";
/**
 * Converts an array of GeoJSON Features to a FeatureCollection.
 *
 * @param features An array of GeoJSON Features.
 * @returns A GeoJSON FeatureCollection containing provided Features.
 */
export function toFeatureCollection(features) {
    return {
        type: "FeatureCollection",
        features: features.filter((feature) => feature),
    };
}
export function emptyFeatureCollection() {
    return {
        type: "FeatureCollection",
        features: [],
    };
}
export function convertGeometryToFeature(geometry, properties) {
    if (geometry) {
        const [type, coordinates] = Object.entries(geometry).find((
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        [_, coordinates]) => coordinates != undefined) || [];
        switch (type) {
            case "Point":
            case "LineString":
            case "Polygon":
                return {
                    type: "Feature",
                    properties: Object.assign({}, properties),
                    geometry: {
                        type,
                        coordinates,
                    },
                };
            case "Circle": {
                const { Center: center, Radius: radius } = coordinates;
                return turfCircle(center, radius, {
                    units: "meters",
                    properties: Object.assign({ center,
                        radius }, properties),
                });
            }
        }
    }
}
